@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Config;
 # ABSTRACT: Load config files for Authentication Milter
 use strict;
 use warnings;
-our $VERSION = '2.20180329'; # VERSION
+our $VERSION = '2.20180430'; # VERSION
 
 use Mail::Milter::Authentication;
 use Module::Load;
@@ -162,7 +162,6 @@ sub get_config {
     if ( exists( $config->{ 'external_callback_processor' } ) ) {
         # Try and load the handler
         my $handler = $config->{ 'external_callback_processor' };
-        warn "Loading external callback processor $handler\n";
         if ( ! is_loaded ( $handler ) ) {
             eval {
                 no strict 'refs'; ## no critic;
@@ -170,7 +169,8 @@ sub get_config {
                 $config->{ '_external_callback_processor' } = $handler->new();
             };
             if ( my $error = $@ ) {
-                warn "Error loading config processor module: $error";
+                delete $config->{ 'external_callback_processor' };
+                warn "Error loading external callback processor module: $error";
             }
         }
     }
@@ -195,7 +195,7 @@ Mail::Milter::Authentication::Config - Load config files for Authentication Milt
 
 =head1 VERSION
 
-version 2.20180329
+version 2.20180430
 
 =head1 SYNOPSIS
 
