@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Handler;
 use strict;
 use warnings;
-our $VERSION = '2.20180329'; # VERSION
+our $VERSION = '2.20180430'; # VERSION
 
 use Digest::MD5 qw{ md5_hex };
 use English qw{ -no_match_vars };
@@ -15,7 +15,7 @@ use Time::HiRes qw{ gettimeofday };
 
 use Mail::Milter::Authentication::Constants qw { :all };
 use Mail::Milter::Authentication::Config;
-use Mail::AuthenticationResults 1.20180314;
+use Mail::AuthenticationResults 1.20180328;
 use Mail::AuthenticationResults::Header;
 use Mail::AuthenticationResults::Header::AuthServID;
 
@@ -188,7 +188,7 @@ sub top_helo_callback {
     $self->status('helo');
     $self->dbgout( 'CALLBACK', 'Helo', LOG_DEBUG );
     $self->set_return( $self->smfis_continue() );
-    $helo_host = q{} if not $helo_host;
+    $helo_host = q{} if ! defined $helo_host;
     my $config = $self->config();
     eval {
         local $SIG{'ALRM'} = sub{ die "Timeout\n" };
@@ -264,7 +264,7 @@ sub top_envfrom_callback {
     $self->status('envfrom');
     $self->dbgout( 'CALLBACK', 'EnvFrom', LOG_DEBUG );
     $self->set_return( $self->smfis_continue() );
-    $env_from = q{} if not $env_from;
+    $env_from = q{} if ! defined $env_from;
     my $config = $self->config();
     eval {
         local $SIG{'ALRM'} = sub{ die "Timeout\n" };
@@ -313,7 +313,7 @@ sub top_envrcpt_callback {
     $self->status('envrcpt');
     $self->dbgout( 'CALLBACK', 'EnvRcpt', LOG_DEBUG );
     $self->set_return( $self->smfis_continue() );
-    $env_to = q{} if not $env_to;
+    $env_to = q{} if ! defined $env_to;
     my $config = $self->config();
     eval {
         local $SIG{'ALRM'} = sub{ die "Timeout\n" };
@@ -355,7 +355,7 @@ sub top_header_callback {
     $self->status('header');
     $self->dbgout( 'CALLBACK', 'Header', LOG_DEBUG );
     $self->set_return( $self->smfis_continue() );
-    $value = q{} if not $value;
+    $value = q{} if ! defined $value;
     my $config = $self->config();
     eval {
         local $SIG{'ALRM'} = sub{ die "Timeout\n" };
@@ -1074,7 +1074,7 @@ sub get_address_from {
 
 sub get_addresses_from {
     my ( $self, $Str ) = @_;
-    $Str = q{} if !defined $Str;
+    $Str = q{} if ! defined $Str;
 
     if ( $Str eq q{} ) {
         $self->log_error( 'Could not parse empty address' );
@@ -1426,6 +1426,9 @@ sub add_headers {
             else {
                 $header_obj->set_indent_by( 4 );
             }
+            if ( exists( $config->{'header_fold_at'} ) ) {
+                $header_obj->set_fold_at( $config->{'header_fold_at'} );
+            }
             $header = $header_obj->as_string();
         }
 
@@ -1581,7 +1584,7 @@ Mail::Milter::Authentication::Handler
 
 =head1 VERSION
 
-version 2.20180329
+version 2.20180430
 
 =head1 DESCRIPTION
 
